# Storm Glass Python

> **Warning**: Storm Glass Python is in active development. The version number is not to be trusted until `1.0.0` is
> reached and breaking changes will be introduced without notice.

[![image](https://img.shields.io/pypi/v/stormglass.svg)](https://pypi.org/project/stormglass/)
[![Build Status](https://github.com/caalle/stormglass-python/workflows/Code%20Quality/badge.svg)](https://github.com/caalle/stormglass-python/workflows/Code%20Quality/badge.svg)
[![Build Status](https://github.com/caalle/stormglass-python/workflows/Release/badge.svg)](https://github.com/caalle/stormglass-python/workflows/Release/badge.svg)
[![Downloads](https://img.shields.io/pypi/dm/stormglass)](https://img.shields.io/pypi/dm/stormglass)
[![](https://img.shields.io/pypi/pyversions/stormglass.svg)](https://pypi.org/pypi/stormglass/)
[![](https://img.shields.io/pypi/l/stormglass.svg)](https://pypi.org/pypi/stormglass/)
[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release)
